From b09ed969be5e118a5b3ab3fdd4109cff7c6a7434 Mon Sep 17 00:00:00 2001
From: Aaron Cannon <cannona@fireantproductions.com>
Date: Mon, 8 Sep 2014 14:19:19 -0500
Subject: [PATCH] Organized list of Braille displays and speech synths. #2722
 #2724

---
 source/braille.py            | 10 +++++++++-
 source/synthDriverHandler.py | 10 +++++++++-
 2 files changed, 18 insertions(+), 2 deletions(-)

diff --git a/source/braille.py b/source/braille.py
index 6971d81..fb70459 100644
--- a/source/braille.py
+++ b/source/braille.py
@@ -309,6 +309,8 @@ def _getDisplayDriver(name):
 
 def getDisplayList():
 	displayList = []
+	# The display that should be placed at the end of the list.
+	lastDisplay = False
 	for loader, name, isPkg in pkgutil.iter_modules(brailleDisplayDrivers.__path__):
 		if name.startswith('_'):
 			continue
@@ -320,11 +322,17 @@ def getDisplayList():
 			continue
 		try:
 			if display.check():
-				displayList.append((display.name, display.description))
+				if display.name == "noBraille":
+					lastDisplay = (display.name, display.description)
+				else:
+					displayList.append((display.name, display.description))
 			else:
 				log.debugWarning("Braille display driver %s reports as unavailable, excluding" % name)
 		except:
 			log.error("", exc_info=True)
+	displayList.sort(key=lambda d : d[1].lower())
+	if lastDisplay:
+		displayList.append(lastDisplay)
 	return displayList
 
 class Region(object):
diff --git a/source/synthDriverHandler.py b/source/synthDriverHandler.py
index 7c2ed9d..86a1da2 100644
--- a/source/synthDriverHandler.py
+++ b/source/synthDriverHandler.py
@@ -39,6 +39,8 @@ def _getSynthDriver(name):
 
 def getSynthList():
 	synthList=[]
+	# The synth that should be placed at the end of the list.
+	lastSynth = False
 	for loader, name, isPkg in pkgutil.iter_modules(synthDrivers.__path__):
 		if name.startswith('_'):
 			continue
@@ -49,11 +51,17 @@ def getSynthList():
 			continue
 		try:
 			if synth.check():
-				synthList.append((synth.name,synth.description))
+				if synth.name == "silence":
+					lastSynth = (synth.name,synth.description)
+				else:
+					synthList.append((synth.name,synth.description))
 			else:
 				log.debugWarning("Synthesizer '%s' doesn't pass the check, excluding from list"%name)
 		except:
 			log.error("",exc_info=True)
+	synthList.sort(key=lambda s : s[1].lower())
+	if lastSynth:
+		synthList.append(lastSynth)
 	return synthList
 
 def getSynth():
-- 
1.9.4.msysgit.1

